/*
  TRT N-Tuple C++ analysis platform
  Original skeleton by Ahmet.Bingul@cern.ch September 2022
  Developments tracked at https://gitlab.cern.ch/atlas-trt-software/TRTnTupleSkeleton
  Compile: g++ skeleton.cpp -o skeleton.exe `root-config --cflags --glibs`
*/

#include "root_head.cpp"

//
// Main program
//
int main(int argc, char** argv) {

  #include "root_book.cpp"
  if(argc>100){ cout << argc << argv; }
  // --- Data chain and tracks ---
  TChain *chain[2];

  chain[0] = new TChain("TRT","TRT N-Tuple");
  chain[0]->Add(input_ntuple_file1.c_str());
  chain[1] = new TChain("TRT","TRT N-Tuple");
  chain[1]->Add(input_ntuple_file2.c_str());


  TRT *Trk, *Track[2];
  Track[0] = new TRT(chain[0]);
  Track[1] = new TRT(chain[1]);

  //#include "includes/dec_pre_loop_info.cpp"
  #include "includes/dec_clock_start.cpp"

  // loop over samples
  for(int j=0; j<2; j++){
  Long64_t n_available_tracks = chain[j]->GetEntries();
  Long64_t n_tracks_to_loop_over = n_available_tracks;

  Trk = Track[j];

  cout << "Sample "<< j+1 << " is running " << endl;
  // === Track loop ======================================================
  for ( Long64_t itrk=0; itrk<n_tracks_to_loop_over; itrk++ ) {

    //#include "includes/dec_progress.cpp"
    Trk->GetEntry(itrk);

    // uncomment to activate track selection criteria
    if ( !isSelectedInDetTrack(Trk) ) continue;

    // global occupancy bin.
    int occ = int(10*Trk->InDetTrackParticles_trackOccupancy);
    if(occ>9) {occ =  9; cout << "occ index has been assigned to 9 since track occupancy is " << Trk->InDetTrackParticles_trackOccupancy << endl;}
    if(occ<0) {occ =  0; cout << "occ index has been assigned to 0 since track occupancy is " << Trk->InDetTrackParticles_trackOccupancy << endl;}
    //int pro = int(10*Trk->InDetTrackParticles_eProbabilityHT);
    //if(pro>9) {pro =  9; cout << "pro index has been assigned to 9 since HT probability is "  << Trk->InDetTrackParticles_eProbabilityHT << endl;}
    //if(pro<0) {pro =  0; cout << "pro index has been assigned to 0 since HT probability is "  << Trk->InDetTrackParticles_eProbabilityHT << endl;}

    int nPrecisionHitsPerTrack[6] = {0};
    int nTubeHitsPerTrack[6] = {0};
    int nOutlierHitsPerTrack[6] = {0};

    // loop over InDet hits for this track
    unsigned int InDetHitVectorSize = indet_hit_vector_size(Trk);
    for ( unsigned int ihit=0; ihit<InDetHitVectorSize; ihit++ )
    {
       int    par       = indet_partition(Trk, ihit); // get partition number
       bool   gas       = indet_isArgon(Trk, ihit);   // 0=Xe, 1=Ar
       bool   isht      = indet_isHT(Trk, ihit);
       int    bec       = Trk->InDetTrackParticles_hit_bec->at(ihit);
       int    layer     = Trk->InDetTrackParticles_hit_layer->at(ihit);
       double time      = Trk->InDetTrackParticles_hit_driftTime->at(ihit);
       double rtow      = Trk->InDetTrackParticles_hit_rTrackToWire->at(ihit);
       bool   isPrecise = indet_isPrecise(Trk, ihit);
       bool   isOutlier = indet_isOutlier(Trk, ihit);
       bool   isTubeHit = indet_isTubehit(Trk, ihit);

       // convert partitionon number to array index
            if(par==-1) par = 0; // BA
       else if(par==+1) par = 1; // BC
       else if(par==+2) par = 2; // EAA
       else if(par==+3) par = 3; // EAB
       else if(par==-2) par = 4; // ECA
       else if(par==-3) par = 5; // ECB
       // convert barrel/endcap number to array index
            if(bec==+1) bec = 0; // BA
       else if(bec==-1) bec = 1; // BC
       else if(bec==+2) bec = 2; // EA
       else if(bec==-2) bec = 3; // EC

       // number of precision hits per track

       nPrecisionHitsPerTrack[par] += isPrecise;
       nTubeHitsPerTrack[par]      += isTubeHit;
       nOutlierHitsPerTrack[par]   += isOutlier;

       if(isPrecise) {
          nPrecisionHits[par]++;
       }

       nTotalHits[par]++;

       //////ePrecise[par][gas]->Fill(isPrecise,par); // TEfficiency object

       if( !isPrecise ) continue;

       double unbiasedResidual = Trk->InDetTrackParticles_hit_unbiasedResidual->at(ihit);

       hResidual[par][gas][occ][j]->Fill(unbiasedResidual); // TH1D object
       eHTprob[bec]->Fill(isht,layer);                      // TEfficiency object
       pRT[par][gas]->Fill(time,rtow);                      // TProfile object
    } // end of hit loop

    for(int j=0;j<6;j++){
        hPrecisionHits[j]->Fill(nPrecisionHitsPerTrack[j]);
             hTubeHits[j]->Fill(nTubeHitsPerTrack[j]);
          hOutlierHits[j]->Fill(nOutlierHitsPerTrack[j]);
    }
  } // === END Track loop ====================================================
  } // end of sample loop

  #include "includes/dec_clock_stop.cpp"

  // Write all histograms and close the file (do this at the end).
  h_out->Write();
  h_out->Close();
  for(int i=0;i<6;i++){
     double r  = (double) nPrecisionHits[i]/nTotalHits[i];
     double e1 = (sqrt(nPrecisionHits[i])/nPrecisionHits[i]);
     double e2 = (sqrt(nTotalHits[i])/nTotalHits[i]);
     double dr = r * sqrt(e1*e1+e2*e2);
     cout << spartition[i] << " : " << nPrecisionHits[i] << " / " << nTotalHits[i] << " = " << r << " +- " << dr<< endl;
  }
  cout << "All OK." << endl;
  return 0;
}
// EOF
