#!/bin/bash
#-------------------------------------------------------------------------------------
# PlotFits.sh
#
# Usage in Linux command line:
#    $ ./PlotFits.sh > htmlfile.html
#
# Last update: Dec 2022
# Author     : Ahmet.Bingul@cern.ch
#-------------------------------------------------------------------------

# define some useful variables
DATE=$(date +'%d %b %Y')
#INPUT=../description.txt
#CONFIGFILE=../config.txt
NTUPLEFILES=data3.txt
NTUPLEFILE1='-'
NTUPLEFILE2='-'
CONTACTEMAIL=Ahmet.Bingul@cern.ch
IMGFOLDER='PngFits'
PNGFILES="$IMGFOLDER/*.png"
THUMBNAILSIZE=350
IFS=';'

#[ ! -f $INPUT ] && { echo "$INPUT file not found!"; exit 99; }
#[ ! -f $CONFIG ] && { echo "$CONFIGFILE file not found!"; exit 99; }
[ ! -f $NTUPLEFILES ] && { echo "$NTUPLEFILES file not found!"; exit 99; }

#---------------------------------------------------------------------------------

NUMBEROFFILES=$(ls -l $IMGFOLDER | wc -l)
TOTALFILESIZE=$(du -hs $IMGFOLDER | awk '{print $1}')
NUMBEROFFILES=$((NUMBEROFFILES-1))

n=1
while read line; do
  if [[ $n -eq 1 ]];
  then
      NTUPLEFILE1=$line
  elif [[ $n -eq 2 ]];
  then
      NTUPLEFILE2=$line
  fi
  n=$((n+1))
done < $NTUPLEFILES

#---------------------------------------------------------------------------------
# html tags start here
IFS=';'
if [[ -d $IMGFOLDER ]]
then
    echo "<!-- TRT NTuple Validation page. : $DATE -->"
    echo "<!-- All images will be extracted from $IMGFOLDER/ directory -->"
else
    echo "$IMGFOLDER/ directory not found!"
    exit 99
fi

echo "<html>"
echo "<head>"
echo "<title>TRT Position Accuracy Analyis</title>"
echo "<STYLE>"
echo "<!--"
echo "   a:link    {color:Blue; text-decoration:underline;}"
echo "   a:active  {color:Red;  text-decoration:underline;}"
echo "   a:visited {color:Blue; text-decoration:underline;}"
echo "   a:hover   {color:Red;  text-decoration:underline;}"
echo "-->"
echo "</STYLE>"
echo "</head>"
echo ""
echo "<body>"
echo "<font face=arial size=5>"
echo "<h1><font color=Brown face=arial>TRT Position Residual Analysis: Fit Results</font></h1>"
echo "<table border=1 bordercolor=silver cellpadding=0 cellspacing=0>"
echo "<tr><td><font face=arial size=4>Input N-Tuple File 1 &nbsp;</font></td>      <td><font face=arial size=4>$NTUPLEFILE1 &nbsp;</font></td></tr>"
echo "<tr><td><font face=arial size=4>Input N-Tuple File 2 &nbsp;</font></td>      <td><font face=arial size=4>$NTUPLEFILE2 &nbsp;</font></td></tr>"
echo "<tr><td><font face=arial size=4>Total number of png files &nbsp;</font></td> <td><font face=arial size=4>$NUMBEROFFILES &nbsp; (<i><a href=$IMGFOLDER>see files</a>)</i></font></td></tr>"
echo "<tr><td><font face=arial size=4>Total size of png files &nbsp;</font></td>   <td><font face=arial size=4>$TOTALFILESIZE</font></td></tr>"
echo "<tr><td><font face=arial size=4>Last update &nbsp;</font></td>               <td><font face=arial size=4>$DATE</font></td></tr>"
echo "<tr><td><font face=arial size=4>Contact &nbsp;</font></td>                   <td><font face=arial size=4><a href=mailto:$CONTACTEMAIL>$CONTACTEMAIL</a></font></td></tr>"
echo "</table>"
echo ""
echo "<hr color=Brown>"
echo "<a href=PlotResiduals.html>Residual Plots</a> | <a href=PlotFits.html>Fit Results</a>"
echo "<hr color=Brown>"
echo "<p>"
echo ""
echo "<TABLE CELLPADDING=0 CELLSPACING=0 BORDER=1 BORDERCOLOR=brown>"
echo "<tr><td><center><font size=6>Sample 1</center></td><td><center><font size=6>Sample 2</center></td>"
i=1
for file in $PNGFILES
do
   if [[ $((i % 2)) -eq 1 ]];
   then
      echo "<tr>"
   fi

   echo "<td><a href=$file><img src=$file border=0 width=$THUMBNAILSIZE></a></td>"

   if [[ $((i % 2)) -eq 0 ]];
   then
      echo "</tr>"
   fi
   i=$((i+1))
done

echo "</TABLE>"
echo "<!-- ---------------------------------------------------------------------- -->"
echo "</font>"
echo "</body>"
echo "</html>"
