//---------------------------------------------------------------------------------------------------
// PlotHTProb.C
//
// This root macro file reads efficiency graphs in input histogram root file
// for BA, BC, EA and EC.
//
// Last update: Jan 2023
// Author     : Ahmet.Bingul@cern.ch
//---------------------------------------------------------------------------------------------------

#include "AtlasStyle.C"
#include "../../TrtBigPaper/TrtBigPaper.cpp"
//#include "../../includes/TRT.C"
//#include "../includes/helpers.cpp"


// -----------------------------------------------------------------------------------
void PlotHTProb(){
  gROOT->Reset();
  //SetAtlasStyle();
  // input root file
  TFile    *rootfile = new TFile("../histograms.root");

  // get the mean and std values from data file
  //for(int j=0; j<m; j++){
  //  hist[j] = trt_big_paper_wrapper(gr[j]);
  //} // for j

   // Andrew's TrtBigPaperOptions
   TrtBigPaperOptions *h_opt = new TrtBigPaperOptions();
   h_opt->status    = "Internal";
   h_opt->simu      = "Simulation";
   h_opt->entriesbw = true;
   h_opt->one       = true;
   h_opt->statbox   = true;
   h_opt->ratio     = false;
   h_opt->showinfo  = false;

   // get list of efficiency plots in root file ------------
   TIter   keyList(rootfile->GetListOfKeys());
   TKey    *key;
   int j=0;
   string bec[4] = {"BA","BC","EA","EC"};
   while ( (key = (TKey*)keyList()) )
   {
      TClass *cl = gROOT->GetClass(key->GetClassName());
      if (!cl->InheritsFrom("TEfficiency")) continue;
      // get plots
      TEfficiency *eff = (TEfficiency*) key->ReadObj();
      // convert
      TH1D *histo = trt_big_paper_wrapper(eff);
      string xlabel = "Module Layer ";
      xlabel += bec[j++];
      histo->SetXTitle(xlabel.c_str());
      histo->SetYTitle("HT Probability");
      // generate png files
      string foldername = "PngHTProb/";
      string pngfile = foldername +eff->GetName();
      h_opt->filename = pngfile;
      TrtBigPaperPlot(histo, histo, h_opt);
   }
   // ------------------------------------------------

} // EOF
