#!/bin/bash
#-------------------------------------------------------------------------------------
# PlotHTProb.sh
#
# Usage in Linux command line:
#    $ ./PlotHTProb.sh > htmlfile.html
#
# Last update: Jan 2023
# Author     : Ahmet.Bingul@cern.ch
#-------------------------------------------------------------------------

# define some useful variables
DATE=$(date +'%d %b %Y')
#INPUT=../description.txt
#CONFIGFILE=../config.txt
CONTACTEMAIL=Ahmet.Bingul@cern.ch
THUMBNAILSIZE=200
DECAYMODE='-'
NTUPLEFILE='-'
HISTOFILE='-'
IMGFOLDER='PngHTProb'
PNGFILES="$IMGFOLDER/*.png"
IFS=';'

#[ ! -f $INPUT ] && { echo "$INPUT file not found!"; exit 99; }
#[ ! -f $CONFIG ] && { echo "$CONFIGFILE file not found!"; exit 99; }

#---------------------------------------------------------------------------------

NUMBEROFFILES=$(ls -l $IMGFOLDER | wc -l)
TOTALFILESIZE=$(du -hs $IMGFOLDER | awk '{print $1}')
NUMBEROFFILES=$((NUMBEROFFILES-1))

#---------------------------------------------------------------------------------
# html tags start here
IFS=';'
if [[ -d $IMGFOLDER ]]
then
    echo "<!-- TRT NTuple Validation page. : $DATE -->"
    echo "<!-- All images will be extracted from $IMGFOLDER/ directory -->"
else
    echo "$IMGFOLDER/ directory not found!"
    exit 99
fi

echo "<html>"
echo "<head>"
echo "<title>TRT HT Probability Analyis</title>"
echo "<STYLE>"
echo "<!--"
echo "   a:link    {color:Blue; text-decoration:underline;}"
echo "   a:active  {color:Red;  text-decoration:underline;}"
echo "   a:visited {color:Blue; text-decoration:underline;}"
echo "   a:hover   {color:Red;  text-decoration:underline;}"
echo "-->"
echo "</STYLE>"
echo "</head>"
echo ""
echo "<body>"
echo "<font face=arial size=5>"
echo "<h1><font color=Brown face=arial>TRT High Threshold Probability Analysis</font></h1>"
echo "<table border=1 bordercolor=silver cellpadding=0 cellspacing=0>"
echo "<tr><td><font face=arial size=4>Input NTuple File &nbsp;</font></td>         <td><font face=arial size=4>$NTUPLEFILE</font></td></tr>"
echo "<tr><td><font face=arial size=4>Signal Decay Mode &nbsp;</font></td>         <td><font face=arial size=4>$DECAYMODE</font></td></tr>"
echo "<tr><td><font face=arial size=4>Histogram File &nbsp;</font></td>            <td><font face=arial size=4>$HISTOFILE</font></td></tr>"
echo "<tr><td><font face=arial size=4>Total number of png files &nbsp;</font></td> <td><font face=arial size=4>$NUMBEROFFILES &nbsp; (<i><a href=$IMGFOLDER>see files</a>)</i></font></td></tr>"
echo "<tr><td><font face=arial size=4>Total size of png files &nbsp;</font></td>   <td><font face=arial size=4>$TOTALFILESIZE</font></td></tr>"
echo "<tr><td><font face=arial size=4>Last update &nbsp;</font></td>               <td><font face=arial size=4>$DATE</font></td></tr>"
echo "<tr><td><font face=arial size=4>Contact &nbsp;</font></td>                   <td><font face=arial size=4><a href=mailto:$CONTACTEMAIL>$CONTACTEMAIL</a></font></td></tr>"
echo "</table>"
echo "<hr color=Brown>"
echo "<p>"
echo ""

echo "<TABLE CELLPADDING=0 CELLSPACING=0 WID3TH=1600 BORDER=1 BORDERCOLOR=brown>"
i=1
for file in $PNGFILES
do
   if [[ $((i % 2)) -eq 1 ]];
   then
      echo "<tr>"
   fi

   echo "<td><a href=$file><img src=$file border=0 width=600></a></td>"

   if [[ $((i % 2)) -eq 0 ]];
   then
      echo "</tr>"
   fi
   i=$((i+1))

done

echo "</TABLE>"
echo "<!-- ---------------------------------------------------------------------- -->"
echo "</font>"
echo "</body>"
echo "</html>"
